@@ -12,7 +12,7 @@ import urllib.parse as path_encoder
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
 #API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
-API_GW = "https://lqv7opk72g.execute-api.cn-north-1.amazonaws.com.cn/api/"
+API_GW = "https://getxmgyi9k.execute-api.cn-north-1.amazonaws.com.cn/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -46,14 +46,20 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     if local_data is not None:
         __upload_one_folder(job_id, FileType.Traindata.name, local_data)
         print(f"upladed {local_data}")
+    else:
+        print("local_data already exists")
 
     if source_code is not None:
         __upload_one_file(job_id, FileType.Code.name, source_code)
         print(f"upladed {source_code}")
+    else:
+        print("source_code already exists")
 
     if weights is not None:
         __upload_one_file(job_id, FileType.Weights.name, weights)
         print(f"upladed {weights}")
+    else:
+        print("weights already exists")
 
     # put hyper param to Dynamodb through API Gateway
     headers = {
@@ -181,6 +187,6 @@ if __name__ == "__main__":
     #getFloderFiles("test")
     #print(files)
     make_tar("yolov5")
-    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+    create_training_job("None", "None", "None", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"10"}})
     #make_tar("train.py")
     #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
